Struct matricks_plugin::MatrixConfiguration
source · pub struct MatrixConfiguration {
pub width: usize,
pub height: usize,
pub target_fps: f32,
pub serpentine: bool,
pub magnification: f32,
}Expand description
Matrix configuration information to be passed to the plugin’s setup function
Fields
width: usizeWidth of the matrix, in number of LEDs
height: usizeHeight of the matrix, in number of LEDs
target_fps: f32FPS that the program will attempt to drive the LEDs
serpentine: boolData line alternates direction between columns or rows In other words, every other row or column is reversed
magnification: f32Magnification of the simulated matrix